==> dif-database-repository-2.4.2-sources.jar: pt/digitalis/dif/dem/managers/impl/model/DIFRepositoryFactory.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import org.hibernate.LobHelper;
import org.hibernate.Session;
import org.hibernate.cfg.Configuration;
import org.hibernate.SessionFactory;
import org.hibernate.context.ThreadLocalSessionContext;


import pt.digitalis.dif.model.hibernate.HibernateUtil;

/**
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DIFRepositoryFactory {

	/** The session factory name. */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains the current session Configuration
     * 
     * @return the Configuration object
     */
    static public Configuration getConfiguration()
    {
        return HibernateUtil.getDatabaseConfiguration(SESSION_FACTORY_NAME, null);
    }

    /**
     * Gets the lob helper.
     *
     * @return the lob helper
     */
    public static LobHelper getLobHelper()
    {
        boolean wasActive = openTransaction();

        LobHelper result = DIFRepositoryFactory.getSession().getLobHelper();

        if (!wasActive)
        {
            DIFRepositoryFactory.getSession().getTransaction().commit();
        }

        return result;
    }

	/**
	 * Obtains the current session
	 *
	 * @return the session object
	 */
    static public Session getSession() 
    {
		SessionFactory sessionFactory = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME);
        Session session = sessionFactory.getCurrentSession();

        if (session != null && !session.isOpen())
        {
            // If session is closed unbind it from the current thread and get a new one
            ThreadLocalSessionContext.unbind(session.getSessionFactory());
            session = sessionFactory.getCurrentSession();
        }

        return session;    	
    }
    
    /**
     * Sets the session factory name.
     * 
     * @param name
     *            the new session factory name
     */
    public static void setSessionFactoryName(String name)
    {
        SESSION_FACTORY_NAME = name;
    }
    
   /**
     * Open transaction. Checks if there are a transaction is active
     *
     * @return true, if the there was a already active transaction
     */
    public static boolean openTransaction()
    {
        boolean wasActive = DIFRepositoryFactory.getSession().getTransaction().isActive();

        if (!wasActive)
        {
            DIFRepositoryFactory.getSession().beginTransaction();
        }
        return wasActive;
    }
}

==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/DIFRepositoryFactory.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import org.hibernate.LobHelper;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.SessionFactory;
import org.hibernate.context.ThreadLocalSessionContext;


import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.TransactionExecuter;
import pt.digitalis.utils.common.IBeanAttributes;

/**
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DIFRepositoryFactory {

	/** The session factory name. */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Execute task same transaction.
     *
     * @param executor
     *            the executor
     * @param beans
     *            the beans
     * @return true, if successful
     */
    public static boolean executeTaskSameTransaction(TransactionExecuter executor, IBeanAttributes... beans)
    {
        boolean success = false;
        boolean wasActive = DIFRepositoryFactory.openTransaction();
        try
        {

            executor.executeLogic(beans);

            if (!wasActive)
            {
                DIFRepositoryFactory.getSession().getTransaction().commit();
            }
            success = true;
        }
        catch (Exception e)
        {
            e.printStackTrace();
            if (!wasActive)
            {
                DIFRepositoryFactory.getSession().getTransaction().rollback();
            }
        }

        return success;
    }

    /**
     * Obtains the current session Configuration
     * 
     * @return the Configuration object
     */
    static public Configuration getConfiguration()
    {
        return HibernateUtil.getDatabaseConfiguration(SESSION_FACTORY_NAME, null);
    }

    /**
     * Gets the lob helper.
     *
     * @return the lob helper
     */
    public static LobHelper getLobHelper()
    {
        boolean wasActive = openTransaction();

        LobHelper result = DIFRepositoryFactory.getSession().getLobHelper();

        if (!wasActive)
        {
            DIFRepositoryFactory.getSession().getTransaction().commit();
        }

        return result;
    }

	/**
	 * Obtains the current session
	 *
	 * @return the session object
	 */
    static public Session getSession() 
    {
		SessionFactory sessionFactory = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME);
        Session session = sessionFactory.getCurrentSession();

        if (session != null && !session.isOpen())
        {
            // If session is closed unbind it from the current thread and get a new one
            ThreadLocalSessionContext.unbind(session.getSessionFactory());
            session = sessionFactory.getCurrentSession();
        }

        return session;    	
    }
    
    /**
     * Sets the session factory name.
     * 
     * @param name
     *            the new session factory name
     */
    public static void setSessionFactoryName(String name)
    {
        SESSION_FACTORY_NAME = name;
    }
    
   /**
     * Open transaction. Checks if there are a transaction is active
     *
     * @return true, if the there was a already active transaction
     */
    public static boolean openTransaction()
    {
        boolean wasActive = DIFRepositoryFactory.getSession().getTransaction().isActive();

        if (!wasActive)
        {
            DIFRepositoryFactory.getSession().beginTransaction();
        }
        return wasActive;
    }
}
